.. _dns:


.. currentmodule:: pyuv


=============================================================
:py:mod:`puyv.dns` --- Asynchronous DNS resolver using c-ares
=============================================================


.. note::
    In order to have a more flexible library from which others could also benefit,
    the c-ares bindings are now `a separated project <https://github.com/saghul/pycares>`_.
    The examples directory contains `an example <https://github.com/saghul/pycares/blob/master/examples/cares-resolver.py>`_
    on how to build a DNS resolver using the ``Channel`` class provided by pycares.

